showstates: Interactive Display of Diver Saturation
Description
Plots a dive profile and interactively displays the diver's nitrogen
saturation state at any intermediate stage indicated by the mouse.
Usage
showstates(d, tissues="DSAT")
Arguments
d
The dive. An object of class "dive".
tissues
Either "DSAT" or "USN" indicating the model.
Value
The vector of nitrogen tensions (in ata) in the most recently clicked
stage.
Details
An object of class "dive" represents a scuba dive.
It is created by the command dive.
This function plots the dive using plot.dive
then waits for the user to click on the plot. This click selects
a time during the dive. The algorithm computes the nitrogen tensions
in the tissues at the indicated time, using haldane,
and plots them as a bar graph. The cumulative oxygen toxicity is also
computed using oxtox.